@@ -249,34 +249,34 @@
 #include "etc/cling/Interpreter/RuntimeOptions.h"
 #include "etc/cling/Interpreter/Value.h"
 #include "etc/cling/Interpreter/Visibility.h"
+// ./core/clingutils/G__forward_listDict.cxx
+#include "forward_list"
 // ./core/clingutils/G__dequeDict.cxx
 #include "deque"
 // ./core/clingutils/G__listDict.cxx
 #include "list"
-// ./core/clingutils/G__forward_listDict.cxx
-#include "forward_list"
-// ./core/clingutils/G__setDict.cxx
-#include "set"
 // ./core/clingutils/G__vectorDict.cxx
 #include "vector"
+// ./core/clingutils/G__setDict.cxx
+#include "set"
 // ./core/clingutils/G__multisetDict.cxx
 #include "set"
-// ./core/clingutils/G__unordered_setDict.cxx
-#include "unordered_set"
 // ./core/clingutils/G__unordered_multisetDict.cxx
 #include "unordered_set"
 // ./core/clingutils/G__multimap2Dict.cxx
 #include "map"
 // ./core/clingutils/G__multimapDict.cxx
 #include "map"
+// ./core/clingutils/G__unordered_setDict.cxx
+#include "unordered_set"
 // ./core/clingutils/G__map2Dict.cxx
 #include "map"
-// ./core/clingutils/G__complexDict.cxx
-#include "root_std_complex.h"
 // ./core/clingutils/G__mapDict.cxx
 #include "map"
 // ./core/clingutils/G__valarrayDict.cxx
 #include "valarray"
+// ./core/clingutils/G__complexDict.cxx
+#include "root_std_complex.h"
 // ./core/clingutils/G__unordered_multimapDict.cxx
 #include "unordered_map"
 // ./core/clingutils/G__unordered_mapDict.cxx
@@ -504,16 +504,11 @@
 #include "Minuit2/ABTypes.h"
 #include "Minuit2/AnalyticalGradientCalculator.h"
 #include "Minuit2/BFGSErrorUpdator.h"
-#include "Minuit2/BasicFunctionGradient.h"
-#include "Minuit2/BasicFunctionMinimum.h"
-#include "Minuit2/BasicMinimumError.h"
-#include "Minuit2/BasicMinimumParameters.h"
-#include "Minuit2/BasicMinimumSeed.h"
-#include "Minuit2/BasicMinimumState.h"
 #include "Minuit2/CombinedMinimizer.h"
 #include "Minuit2/CombinedMinimumBuilder.h"
 #include "Minuit2/ContoursError.h"
 #include "Minuit2/DavidonErrorUpdator.h"
+#include "Minuit2/ExternalInternalGradientCalculator.h"
 #include "Minuit2/FCNAdapter.h"
 #include "Minuit2/FCNBase.h"
 #include "Minuit2/FCNGradAdapter.h"
@@ -592,6 +587,7 @@
 #include "Minuit2/ModularFunctionMinimizer.h"
 #include "Minuit2/NegativeG2LineSearch.h"
 #include "Minuit2/Numerical2PGradientCalculator.h"
+#include "Minuit2/NumericalDerivator.h"
 #include "Minuit2/ParametricFunction.h"
 #include "Minuit2/ScanBuilder.h"
 #include "Minuit2/ScanMinimizer.h"
@@ -766,7 +762,6 @@
 // ./math/genetic/G__Genetic.cxx
 #include "Math/GeneticMinimizer.h"
 // ./math/vecops/G__ROOTVecOps.cxx
-#include "ROOT/RAdoptAllocator.hxx"
 #include "ROOT/RVec.hxx"
 // ./hist/hist/G__Hist.cxx
 #include "Foption.h"
@@ -945,6 +940,7 @@
 #include "TTreeSQL.h"
 #include "TVirtualIndex.h"
 #include "TVirtualTreePlayer.h"
+#include "ROOT/InternalTreeUtils.hxx"
 #include "ROOT/TIOFeatures.hxx"
 // ./tree/treeplayer/G__TreePlayer.cxx
 #include "ROOT/TTreeReaderFast.hxx"
@@ -984,7 +980,6 @@
 // ./tree/treeviewer/G__TreeViewer.cxx
 #include "HelpTextTV.h"
 #include "TGTreeTable.h"
-#include "TMemStatShow.h"
 #include "TParallelCoordEditor.h"
 #include "TParallelCoord.h"
 #include "TParallelCoordRange.h"
@@ -1000,8 +995,8 @@
 #include "ROOT/RDataSource.hxx"
 #include "ROOT/RDFHelpers.hxx"
 #include "ROOT/RLazyDS.hxx"
-#include "ROOT/RResultPtr.hxx"
 #include "ROOT/RResultHandle.hxx"
+#include "ROOT/RResultPtr.hxx"
 #include "ROOT/RRootDS.hxx"
 #include "ROOT/RSnapshotOptions.hxx"
 #include "ROOT/RTrivialDS.hxx"
@@ -1011,16 +1006,19 @@
 #include "ROOT/RDF/GraphUtils.hxx"
 #include "ROOT/RDF/HistoModels.hxx"
 #include "ROOT/RDF/InterfaceUtils.hxx"
+#include "ROOT/RDF/InternalUtils.hxx"
 #include "ROOT/RDF/RActionBase.hxx"
 #include "ROOT/RDF/RAction.hxx"
-#include "ROOT/RDF/RBookedDefines.hxx"
-#include "ROOT/RDF/RDataBlockNotifier.hxx"
+#include "ROOT/RDF/RColumnRegister.hxx"
+#include "ROOT/RDF/RNewSampleNotifier.hxx"
+#include "ROOT/RDF/RSampleInfo.hxx"
 #include "ROOT/RDF/RDefineBase.hxx"
 #include "ROOT/RDF/RDefine.hxx"
 #include "ROOT/RDF/RDefineReader.hxx"
 #include "ROOT/RDF/RDSColumnReader.hxx"
 #include "ROOT/RDF/RColumnReaderBase.hxx"
 #include "ROOT/RDF/RCutFlowReport.hxx"
+#include "ROOT/RDF/RDatasetSpec.hxx"
 #include "ROOT/RDF/RDisplay.hxx"
 #include "ROOT/RDF/RFilterBase.hxx"
 #include "ROOT/RDF/RFilter.hxx"
@@ -1028,16 +1026,24 @@
 #include "ROOT/RDF/RJittedAction.hxx"
 #include "ROOT/RDF/RJittedDefine.hxx"
 #include "ROOT/RDF/RJittedFilter.hxx"
+#include "ROOT/RDF/RJittedVariation.hxx"
 #include "ROOT/RDF/RLazyDSImpl.hxx"
 #include "ROOT/RDF/RLoopManager.hxx"
 #include "ROOT/RDF/RMergeableValue.hxx"
 #include "ROOT/RDF/RNodeBase.hxx"
 #include "ROOT/RDF/RRangeBase.hxx"
 #include "ROOT/RDF/RRange.hxx"
+#include "ROOT/RDF/RResultMap.hxx"
 #include "ROOT/RDF/RSlotStack.hxx"
 #include "ROOT/RDF/RTreeColumnReader.hxx"
+#include "ROOT/RDF/RVariation.hxx"
+#include "ROOT/RDF/RVariationBase.hxx"
+#include "ROOT/RDF/RVariationReader.hxx"
+#include "ROOT/RDF/RVariationsDescription.hxx"
+#include "ROOT/RDF/RVariedAction.hxx"
 #include "ROOT/RDF/Utils.hxx"
 #include "ROOT/RDF/PyROOTHelpers.hxx"
+#include "ROOT/RDF/RDFDescription.hxx"
 #include "ROOT/RSqliteDS.hxx"
 #include "ROOT/RNTupleDS.hxx"
 // ./tree/ntuple/G__ROOTNTuple.cxx
@@ -1057,17 +1063,21 @@
 #include "ROOT/RNTupleMetrics.hxx"
 #include "ROOT/RNTupleModel.hxx"
 #include "ROOT/RNTupleOptions.hxx"
+#include "ROOT/RNTupleSerialize.hxx"
 #include "ROOT/RNTupleUtil.hxx"
 #include "ROOT/RNTupleView.hxx"
 #include "ROOT/RNTupleZip.hxx"
 #include "ROOT/RPage.hxx"
 #include "ROOT/RPageAllocator.hxx"
 #include "ROOT/RPagePool.hxx"
+#include "ROOT/RPageSinkBuf.hxx"
+#include "ROOT/RPageSourceFriends.hxx"
 #include "ROOT/RPageStorage.hxx"
 #include "ROOT/RPageStorageFile.hxx"
 // ./io/io/G__RIO.cxx
 #include "ROOT/RRawFile.hxx"
 #include "ROOT/RRawFileUnix.hxx"
+#include "ROOT/RIoUring.hxx"
 #include "ROOT/TBufferMerger.hxx"
 #include "TArchiveFile.h"
 #include "TBufferFile.h"
@@ -1139,6 +1149,7 @@
 #include "TNetXNGFile.h"
 #include "TNetXNGFileStager.h"
 #include "TNetXNGSystem.h"
+#include "ROOT/RRawFileNetXNG.hxx"
 // ./graf2d/gpadv7/G__ROOTGpadv7.cxx
 #include "ROOT/RCanvas.hxx"
 #include "ROOT/RFrame.hxx"
@@ -1147,11 +1158,12 @@
 #include "ROOT/RDisplayItem.hxx"
 #include "ROOT/RAttrMap.hxx"
 #include "ROOT/RAttrBase.hxx"
+#include "ROOT/RAttrAggregation.hxx"
 #include "ROOT/RAttrAxis.hxx"
-#include "ROOT/RAttrBox.hxx"
-#include "ROOT/RAttrColor.hxx"
+#include "ROOT/RAttrBorder.hxx"
 #include "ROOT/RAttrLine.hxx"
 #include "ROOT/RAttrFill.hxx"
+#include "ROOT/RAttrFont.hxx"
 #include "ROOT/RAttrMarker.hxx"
 #include "ROOT/RAttrMargins.hxx"
 #include "ROOT/RAttrText.hxx"
@@ -1160,6 +1172,7 @@
 #include "ROOT/RPalette.hxx"
 #include "ROOT/RPaletteDrawable.hxx"
 #include "ROOT/RDrawable.hxx"
+#include "ROOT/ROnFrameDrawable.hxx"
 #include "ROOT/RDrawableRequest.hxx"
 #include "ROOT/RStyle.hxx"
 #include "ROOT/RPadDisplayItem.hxx"
@@ -1168,12 +1181,13 @@
 #include "ROOT/RPad.hxx"
 #include "ROOT/RPadLength.hxx"
 #include "ROOT/RPadPos.hxx"
-#include "ROOT/RPadUserAxis.hxx"
 #include "ROOT/RPave.hxx"
 #include "ROOT/RVirtualCanvasPainter.hxx"
+#include "ROOT/TObjectDisplayItem.hxx"
 #include "ROOT/TObjectDrawable.hxx"
 // ./graf2d/primitivesv7/G__ROOTGraphicsPrimitives.cxx
 #include "ROOT/RBox.hxx"
+#include "ROOT/RFont.hxx"
 #include "ROOT/RFrameTitle.hxx"
 #include "ROOT/RLegend.hxx"
 #include "ROOT/RLine.hxx"
@@ -1702,8 +1716,28 @@
 #include "TMVA/MethodPyKeras.h"
 #include "TMVA/MethodPyRandomForest.h"
 #include "TMVA/MethodPyTorch.h"
+#include "TMVA/RModelParser_Keras.h"
+#include "TMVA/RModelParser_PyTorch.h"
 #include "TMVA/PyMethodBase.h"
+// ./tmva/sofie/G__ROOTTMVASofie.cxx
+#include "TMVA/OperatorList.hxx"
+#include "TMVA/RModel.hxx"
+#include "TMVA/ROperator.hxx"
+#include "TMVA/ROperator_Add.hxx"
+#include "TMVA/ROperator_BatchNormalization.hxx"
+#include "TMVA/ROperator_Conv.hxx"
+#include "TMVA/ROperator_Gemm.hxx"
+#include "TMVA/ROperator_Relu.hxx"
+#include "TMVA/ROperator_Reshape.hxx"
+#include "TMVA/ROperator_Selu.hxx"
+#include "TMVA/ROperator_Sigmoid.hxx"
+#include "TMVA/ROperator_Slice.hxx"
+#include "TMVA/ROperator_Transpose.hxx"
+#include "TMVA/ROperator_Pool.hxx"
+#include "TMVA/SOFIE_common.hxx"
 // ./roofit/roofitcore/G__RooFitCore.cxx
+#include "RooFit/Detail/DataMap.h"
+#include "RooFit/Floats.h"
 #include "Roo1DTable.h"
 #include "RooAbsAnaConvPdf.h"
 #include "RooAbsArg.h"
@@ -1723,6 +1757,7 @@
 #include "RooAbsIntegrator.h"
 #include "RooAbsLValue.h"
 #include "RooAbsMCStudyModule.h"
+#include "RooAbsMinimizerFcn.h"
 #include "RooAbsMoment.h"
 #include "RooAbsNumGenerator.h"
 #include "RooAbsOptTestStatistic.h"
@@ -1805,7 +1840,6 @@
 #include "RooGenProdProj.h"
 #include "RooGlobalFunc.h"
 #include "RooGrid.h"
-#include "RooHashTable.h"
 #include "RooHistError.h"
 #include "RooHistFunc.h"
 #include "RooHist.h"
@@ -1816,6 +1850,7 @@
 #include "RooIntegratorBinding.h"
 #include "RooInt.h"
 #include "RooInvTransform.h"
+#include "RooLinearCombination.h"
 #include "RooLinearVar.h"
 #include "RooLinkedListElem.h"
 #include "RooLinkedList.h"
@@ -1823,13 +1858,12 @@
 #include "RooLinTransBinning.h"
 #include "RooList.h"
 #include "RooListProxy.h"
-#include "RooMappedCategory.h"
 #include "RooMath.h"
+#include "RooMappedCategory.h"
 #include "RooMCIntegrator.h"
 #include "RooMCStudy.h"
 #include "RooMinimizerFcn.h"
 #include "RooMinimizer.h"
-#include "RooMinuit.h"
 #include "RooMoment.h"
 #include "RooMPSentinel.h"
 #include "RooMsgService.h"
@@ -1837,7 +1871,6 @@
 #include "RooMultiGenFunction.h"
 #include "RooMultiVarGaussian.h"
 #include "RooNameReg.h"
-#include "RooNameSet.h"
 #include "RooNLLVar.h"
 #include "RooNormSetCache.h"
 #include "RooNumber.h"
@@ -1853,6 +1886,7 @@
 #include "RooParamBinning.h"
 #include "RooPlotable.h"
 #include "RooPlot.h"
+#include "RooPolyFunc.h"
 #include "RooPolyVar.h"
 #include "RooPrintable.h"
 #include "RooProdGenContext.h"
@@ -1863,6 +1897,7 @@
 #include "RooProofDriverSelector.h"
 #include "RooPullVar.h"
 #include "RooQuasiRandomGenerator.h"
+#include "RooRatio.h"
 #include "RooRandom.h"
 #include "RooRandomizeParamMCSModule.h"
 #include "RooRangeBinning.h"
@@ -1887,7 +1922,6 @@
 #include "RooSegmentedIntegrator1D.h"
 #include "RooSegmentedIntegrator2D.h"
 #include "RooSentinel.h"
-#include "RooSetPair.h"
 #include "RooSetProxy.h"
 #include "RooSharedProperties.h"
 #include "RooSimGenContext.h"
@@ -1917,9 +1951,25 @@
 #include "RooWrapperPdf.h"
 #include "RooNaNPacker.h"
 #include "RooBinSamplingPdf.h"
+#include "RooBinWidthFunction.h"
 #include "RooFitLegacy/RooCatTypeLegacy.h"
 #include "RooFitLegacy/RooCategorySharedProperties.h"
+#include "RooFitLegacy/RooHashTable.h"
+#include "RooFitLegacy/RooMinuit.h"
+#include "RooFitLegacy/RooNameSet.h"
+#include "RooFitLegacy/RooSetPair.h"
 #include "RooFitLegacy/RooTreeData.h"
+#include "RooFit/TestStatistics/LikelihoodGradientWrapper.h"
+#include "RooFit/TestStatistics/LikelihoodWrapper.h"
+#include "RooFit/TestStatistics/RooAbsL.h"
+#include "RooFit/TestStatistics/RooBinnedL.h"
+#include "RooFit/TestStatistics/RooSubsidiaryL.h"
+#include "RooFit/TestStatistics/RooSumL.h"
+#include "RooFit/TestStatistics/RooRealL.h"
+#include "RooFit/TestStatistics/RooUnbinnedL.h"
+#include "RooFit/TestStatistics/optional_parameter_types.h"
+#include "RooFit/TestStatistics/buildLikelihood.h"
+#include "RunContext.h"
 // ./roofit/roofit/G__RooFit.cxx
 #include "Roo2DKeysPdf.h"
 #include "RooArgusBG.h"
@@ -1954,6 +2004,7 @@
 #include "RooIntegralMorph.h"
 #include "RooJeffreysPrior.h"
 #include "RooKeysPdf.h"
+#include "RooLagrangianMorphFunc.h"
 #include "RooLandau.h"
 #include "RooLognormal.h"
 #include "RooMathCoreReg.h"
@@ -2056,7 +2107,6 @@
 // ./roofit/histfactory/G__HistFactory.cxx
 #include "RooStats/HistFactory/Asimov.h"
 #include "RooStats/HistFactory/Channel.h"
-#include "RooStats/HistFactory/ConfigParser.h"
 #include "RooStats/HistFactory/Data.h"
 #include "RooStats/HistFactory/EstimateSummary.h"
 #include "RooStats/HistFactory/FlexibleInterpVar.h"
@@ -2076,6 +2126,13 @@
 #include "RooStats/HistFactory/RooBarlowBeestonLL.h"
 #include "RooStats/HistFactory/Sample.h"
 #include "RooStats/HistFactory/Systematics.h"
+#include "RooStats/HistFactory/ConfigParser.h"
+// ./roofit/RDataFrameHelpers/G__RooFitRDataFrameHelpers.cxx
+#include "RooAbsDataHelper.h"
+// ./roofit/hs3/G__RooFitHS3.cxx
+#include "RooFitHS3/RooJSONFactoryWSTool.h"
+#include "RooFitHS3/HistFactoryJSONTool.h"
+#include "RooFitHS3/JSONInterface.h"
 // ./core/G__Core.cxx
 #include "ROOT/TErrorDefaultHandler.hxx"
 #include "ROOT/TSequentialExecutor.hxx"
@@ -2210,12 +2267,12 @@
 #include "RStringView.h"
 #include "TClassEdit.h"
 #include "TError.h"
-#include "ROOT/RIntegerSequence.hxx"
 #include "ROOT/RLogger.hxx"
-#include "ROOT/RMakeUnique.hxx"
 #include "ROOT/RNotFn.hxx"
+#include "ROOT/RRangeCast.hxx"
 #include "ROOT/RSpan.hxx"
 #include "ROOT/RStringView.hxx"
+#include "ROOT/StringUtils.hxx"
 #include "ROOT/span.hxx"
 #include "ROOT/TypeTraits.hxx"
 #include "TUnixSystem.h"
